==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/MarkedStateAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p135820_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p874817_="https://jakarta.ee/xml/ns/jaxb" xmlns:p942898_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation, that provides a "marked state" for a selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for MarkedStateAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="MarkedStateAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseReplyType">
 *       <attribute name="markedState" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MarkedStateAnnotationType")
public class MarkedStateAnnotationType
    extends BaseReplyType
{

    @XmlAttribute(name = "markedState")
    protected Boolean markedState;

    /**
     * Gets the value of the markedState property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isMarkedState() {
        if (markedState == null) {
            return true;
        } else {
            return markedState;
        }
    }

    /**
     * Sets the value of the markedState property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setMarkedState(boolean value) {
        this.markedState = value;
    }

    public boolean isSetMarkedState() {
        return (this.markedState!= null);
    }

    public void unsetMarkedState() {
        this.markedState = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/MarkedStateAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p105796_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p913707_="https://jakarta.ee/xml/ns/jaxb" xmlns:p931759_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation, that provides a "marked state" for a selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for MarkedStateAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="MarkedStateAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseReplyType">
 *       <attribute name="markedState" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MarkedStateAnnotationType")
public class MarkedStateAnnotationType
    extends BaseReplyType
{

    @XmlAttribute(name = "markedState")
    protected Boolean markedState;

    /**
     * Gets the value of the markedState property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isMarkedState() {
        if (markedState == null) {
            return true;
        } else {
            return markedState;
        }
    }

    /**
     * Sets the value of the markedState property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setMarkedState(boolean value) {
        this.markedState = value;
    }

    public boolean isSetMarkedState() {
        return (this.markedState!= null);
    }

    public void unsetMarkedState() {
        this.markedState = null;
    }

}
